#[non_exhaustive]#[repr(C)]pub enum PixelFormat {
Rgb,
Bgr,
U8,
Unknown {
red_position: u8,
green_position: u8,
blue_position: u8,
},
}Expand description
Color format of pixels in the framebuffer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rgb
One byte red, then one byte green, then one byte blue.
Length might be larger than 3, check bytes_per_pixel
for this.
Bgr
One byte blue, then one byte green, then one byte red.
Length might be larger than 3, check bytes_per_pixel
for this.
U8
A single byte, representing the grayscale value.
Length might be larger than 1, check bytes_per_pixel
for this.
Unknown
Unknown pixel format.